@@ -266,6 +266,7 @@ class MbstringTest extends TestCase
             $this->assertSame('Déjà Σσσ Iı Ii İi̇', p::mb_convert_case('DÉJÀ ΣΣΣ ıı iI İİ', \MB_CASE_TITLE));
         }
         $this->assertSame('ab', str_replace('?', '', mb_strtolower(urldecode('a%A1%C0b'))));
+        $this->assertSame('hi ssΐὤιմխ', p::mb_convert_case('HI ßΐᾬﬗ', p::MB_CASE_FOLD));
     }
 
     /**
@@ -466,6 +467,53 @@ class MbstringTest extends TestCase
         $this->assertTrue(mb_check_encoding("\xE9", 'Windows-1252'));
     }
 
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_check_encoding
+     *
+     * @requires PHP 7.2
+     */
+    public function testCheckEncodingWithArrayValue()
+    {
+        $this->assertTrue(mb_check_encoding(['aςσb'], 'UTF8'));
+        $this->assertTrue(mb_check_encoding(['abc'], 'ASCII'));
+        $this->assertTrue(mb_check_encoding(["\xE9"], 'Windows-1252'));
+
+        $this->assertTrue(mb_check_encoding(['aςσb', 'abc'], 'UTF8'));
+        $this->assertTrue(mb_check_encoding(["\xE9", 'abc'], 'Windows-1252'));
+
+        $this->assertFalse(mb_check_encoding(['aςσb', "\xE9"], 'UTF8'));
+        $this->assertFalse(mb_check_encoding(['abc', "\xE9"], 'ASCII'));
+        $this->assertFalse(mb_check_encoding(['abc', 'aςσb'], 'ASCII'));
+
+        $this->assertTrue(mb_check_encoding(["\xE9" => "\xE9", 'abc' => 'abc'], 'Windows-1252'));
+        $this->assertTrue(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => 'abc'], 'UTF8'));
+
+        $this->assertFalse(mb_check_encoding(['aςσb' => 'aςσb', "\xE9" => 'abc'], 'UTF8'));
+
+
+        $this->assertTrue(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc', 'aςσb']], 'UTF8'));
+        $this->assertTrue(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc' => 'abc', 'aςσb' => 'aςσb']], 'UTF8'));
+
+
+        $this->assertFalse(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc' => 'abc', 'aςσb' => "\xE9"]], 'UTF8'));
+        $this->assertFalse(mb_check_encoding(['aςσb' => 'aςσb', 'abc' => ['abc' => 'abc', "\xE9" => 'aςσb']], 'UTF8'));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_check_encoding
+     *
+     * @requires PHP < 7.2
+     */
+    public function testCheckEncodingWithArrayValueForPhpLessThan72()
+    {
+        $errorMessage = null;
+        set_error_handler(function ($type, $msg, $file, $line) use (&$errorMessage) { $errorMessage = \E_USER_WARNING === $type || \E_WARNING === $type ? $msg : null; });
+        $this->assertNull(mb_check_encoding(['aςσb'], 'UTF8'));
+        restore_error_handler();
+        $this->assertSame('mb_check_encoding() expects parameter 1 to be string, array given', $errorMessage);
+    }
+
+
     /**
      * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_detect_encoding
      */
@@ -579,4 +627,104 @@ class MbstringTest extends TestCase
         $this->assertSame(sprintf('Test: %s', base64_decode('7/Du4uXw6uA=')), mb_decode_mimeheader('Test: =?windows-1251?B?7/Du4uXw6uA=?='));
         $this->assertTrue(mb_internal_encoding('utf8'));
     }
+
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_str_pad
+     *
+     * @dataProvider paddingStringProvider
+     * @dataProvider paddingEmojiProvider
+     * @dataProvider paddingEncodingProvider
+     */
+    public function testMbStrPad(string $expectedResult, string $string, int $length, string $padString, int $padType, string $encoding = null): void
+    {
+        if ('UTF-32' === $encoding && \PHP_VERSION_ID < 73000) {
+            $this->markTestSkipped('PHP < 7.3 doesn\'t handle UTF-32 encoding properly');
+        }
+
+        $this->assertSame($expectedResult, mb_convert_encoding(mb_str_pad($string, $length, $padString, $padType, $encoding), 'UTF-8', $encoding ?? mb_internal_encoding()));
+    }
+
+    /**
+     * @covers \Symfony\Polyfill\Mbstring\Mbstring::mb_str_pad
+     *
+     * @dataProvider mbStrPadInvalidArgumentsProvider
+     */
+    public function testMbStrPadInvalidArguments(string $expectedError, string $string, int $length, string $padString, int $padType, string $encoding = null): void
+    {
+        $this->expectException(\ValueError::class);
+        $this->expectErrorMessage($expectedError);
+
+        mb_str_pad($string, $length, $padString, $padType, $encoding);
+    }
+
+    public static function paddingStringProvider(): iterable
+    {
+        // Simple ASCII strings
+        yield ['+Hello+', 'Hello', 7, '+-', \STR_PAD_BOTH];
+        yield ['+-World+-+', 'World', 10, '+-', \STR_PAD_BOTH];
+        yield ['+-Hello', 'Hello', 7, '+-', \STR_PAD_LEFT];
+        yield ['+-+-+World', 'World', 10, '+-', \STR_PAD_LEFT];
+        yield ['Hello+-', 'Hello', 7, '+-', \STR_PAD_RIGHT];
+        yield ['World+-+-+', 'World', 10, '+-', \STR_PAD_RIGHT];
+        // Edge cases pad length
+        yield ['▶▶', '▶▶', 2, ' ', \STR_PAD_BOTH];
+        yield ['▶▶', '▶▶', 1, ' ', \STR_PAD_BOTH];
+        yield ['▶▶', '▶▶', 0, ' ', \STR_PAD_BOTH];
+        yield ['▶▶', '▶▶', -1, ' ', \STR_PAD_BOTH];
+        // Empty input string
+        yield ['  ', '', 2, ' ', \STR_PAD_BOTH];
+        yield [' ', '', 1, ' ', \STR_PAD_BOTH];
+        yield ['', '', 0, ' ', \STR_PAD_BOTH];
+        yield ['', '', -1, ' ', \STR_PAD_BOTH];
+        // Default argument
+        yield ['▶▶    ', '▶▶', 6, ' ', \STR_PAD_RIGHT];
+        yield ['    ▶▶', '▶▶', 6, ' ', \STR_PAD_LEFT];
+        yield ['  ▶▶  ', '▶▶', 6, ' ', \STR_PAD_BOTH];
+    }
+
+    public static function paddingEmojiProvider(): iterable
+    {
+        // UTF-8 Emojis
+        yield ['▶▶❤❓❇❤', '▶▶', 6, '❤❓❇', \STR_PAD_RIGHT];
+        yield ['❤❓❇❤▶▶', '▶▶', 6, '❤❓❇', \STR_PAD_LEFT];
+        yield ['❤❓▶▶❤❓', '▶▶', 6, '❤❓❇', \STR_PAD_BOTH];
+        yield ['▶▶❤❓❇', '▶▶', 5, '❤❓❇', \STR_PAD_RIGHT];
+        yield ['❤❓❇▶▶', '▶▶', 5, '❤❓❇', \STR_PAD_LEFT];
+        yield ['❤▶▶❤❓', '▶▶', 5, '❤❓❇', \STR_PAD_BOTH];
+        yield ['▶▶❤❓', '▶▶', 4, '❤❓❇', \STR_PAD_RIGHT];
+        yield ['❤❓▶▶', '▶▶', 4, '❤❓❇', \STR_PAD_LEFT];
+        yield ['❤▶▶❤', '▶▶', 4, '❤❓❇', \STR_PAD_BOTH];
+        yield ['▶▶❤', '▶▶', 3, '❤❓❇', \STR_PAD_RIGHT];
+        yield ['❤▶▶', '▶▶', 3, '❤❓❇', \STR_PAD_LEFT];
+        yield ['▶▶❤', '▶▶', 3, '❤❓❇', \STR_PAD_BOTH];
+
+        for ($i = 2; $i >= 0; --$i) {
+            yield ['▶▶', '▶▶', $i, '❤❓❇', \STR_PAD_RIGHT];
+            yield ['▶▶', '▶▶', $i, '❤❓❇', \STR_PAD_LEFT];
+            yield ['▶▶', '▶▶', $i, '❤❓❇', \STR_PAD_BOTH];
+        }
+    }
+
+    public static function paddingEncodingProvider(): iterable
+    {
+        $string = 'Σὲ γνωρίζω ἀπὸ τὴν κόψη Зарегистрируйтесь';
+
+        foreach (['UTF-8', 'UTF-32', 'UTF-7'] as $encoding) {
+            $input = mb_convert_encoding($string, $encoding, 'UTF-8');
+            $padStr = mb_convert_encoding('▶▶', $encoding, 'UTF-8');
+
+            yield ['Σὲ γνωρίζω ἀπὸ τὴν κόψη Зарегистрируйтесь▶▶▶', $input, 44, $padStr, \STR_PAD_RIGHT, $encoding];
+            yield ['▶▶▶Σὲ γνωρίζω ἀπὸ τὴν κόψη Зарегистрируйтесь', $input, 44, $padStr, \STR_PAD_LEFT, $encoding];
+            yield ['▶Σὲ γνωρίζω ἀπὸ τὴν κόψη Зарегистрируйтесь▶▶', $input, 44, $padStr, \STR_PAD_BOTH, $encoding];
+        }
+    }
+
+    public static function mbStrPadInvalidArgumentsProvider(): iterable
+    {
+        yield ['mb_str_pad(): Argument #3 ($pad_string) must be a non-empty string', '▶▶', 6, '', \STR_PAD_RIGHT];
+        yield ['mb_str_pad(): Argument #3 ($pad_string) must be a non-empty string', '▶▶', 6, '', \STR_PAD_LEFT];
+        yield ['mb_str_pad(): Argument #3 ($pad_string) must be a non-empty string', '▶▶', 6, '', \STR_PAD_BOTH];
+        yield ['mb_str_pad(): Argument #4 ($pad_type) must be STR_PAD_LEFT, STR_PAD_RIGHT, or STR_PAD_BOTH', '▶▶', 6, ' ', 123456];
+        yield ['mb_str_pad(): Argument #5 ($encoding) must be a valid encoding, "unexisting" given', '▶▶', 6, ' ', \STR_PAD_BOTH, 'unexisting'];
+    }
 }
